#' @title onpoint
#'
#' @description
#' Growing collection of small helper functions for point pattern analysis. Most functions
#' are designed to work with the spatstat package.
#'
#' @name onpoint
#' @docType package
#' @keywords internal
"_PACKAGE"

# Global variables
globalVariables(c(
  "aggregate",
  "hi", "high",
  "is",
  "lo", "low",
  "marks",
  "obs", "observed",
  "r",
  "theo", "theoretical", "type",
  "x.min", "x.max",
  "y"))
